@@ -68,7 +68,8 @@ class Object():
             self.guid=guid
             self.__dict__.update(kwargs)
             if not isinstance(self.__class__.__dict__.get('endpoint'), property):
-                self.endpoint=getattr(self.__class__, 'endpoint').format(guid=self.guid)
+                if "endpoint" in dir(self.__class__):
+                    self.endpoint=getattr(self.__class__, 'endpoint').format(guid=self.guid)
 
         else:
             raise AttributeError("Must specify either `guid` or `**kwargs`")
@@ -111,7 +112,7 @@ class Object():
         elif name in self.__dict__:
             return self.__dict__[name]
         elif name in dir(self):
-            return getattr(self.__class__, name)
+            return getattr(self.__class__, name).fget(self)
         else:
             raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{name}'")
 
@@ -146,18 +147,17 @@ class Object():
 
         self.__dict__.update(data)
 
-    def update(self, data=None):
+    def update(**kwargs):
         """
         Updates the object properties in Arena based on attributes passed in.
 
-        Required arguments:
-
-        - data - A dictionary of object properties to update
+        Keyword arguments are required
         """
 
-        data=data or self.__dict__
+        if not kwargs:
+            raise ValueError("Must include parameter keyword arguments")
 
-        data= self._client._put(self.endpoint, data)
+        data= self._client._put(self.endpoint, kwargs)
 
         self.__dict__.update(data)
 
